<template>
  <div class="notice">
    <el-dialog
        v-model="dialogVisible"
        :title="state.title"
        width="50%"
        :before-close="handleClose"
        :close-on-press-escape="false"
        :close-on-click-modal="false"
    >
      <el-form :model="state.form" size="default" ref="superRef" :rules="state.formRules" label-width="150px" >
        <el-form-item v-if="state.isAdmin" label="企业：" prop="companyId">
          <el-select v-model="state.form.companyId" placeholder="请选择" clearable @change="getCompanyUser">
            <el-option
                v-for="item in state.companyList"
                :key="item.id"
                :label="item.name"
                :value="item.id">
            </el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="年份:" prop="year">
          <el-date-picker
              v-model="state.form.year"
              type="year"
              value-format="YYYY"
              placeholder="请选择年份"
          />
        </el-form-item>
        <el-form-item label="编号:" prop="number">
          <el-input v-model.trim="state.form.number" :readonly="state.title =='查看'" placeholder="编号"></el-input>
        </el-form-item>
        <el-form-item label="评审目的:" prop="objective">
          <el-input v-model.trim="state.form.objective" type="textarea" :readonly="state.title =='查看'" :autosize="{ minRows: 2 }"></el-input>
        </el-form-item>
        <el-form-item label="评审内容:" prop="content">
          <el-input v-model.trim="state.form.content" type="textarea" :readonly="state.title =='查看'" :autosize="{ minRows: 2 }"></el-input>
        </el-form-item>
        <el-form-item label="评审时间、地点及方式:" prop="location">
          <el-input v-model.trim="state.form.location" type="textarea" :readonly="state.title =='查看'" :autosize="{ minRows: 2 }"></el-input>
        </el-form-item>
        <el-form-item label="参与评审人员:" prop="staff">
          <el-input v-model.trim="state.form.staff" type="textarea" :readonly="state.title =='查看'" :autosize="{ minRows: 2 }"></el-input>
        </el-form-item>
        <el-form-item label="管理评审输入报告:" prop="report">
          <el-input v-model.trim="state.form.report" type="textarea" :readonly="state.title =='查看'" :autosize="{ minRows: 2 }"></el-input>
        </el-form-item>
        <el-row>
          <el-col :sm="24" :md="12">
            <el-form-item label="编制:" prop="fictionId">
              <el-select clearable v-model="state.form.fictionId" :disabled="state.title =='查看'" filterable placeholder="编制" style="width: 100%">
                <el-option
                    v-for="item in state.userList"
                    :key="item.id"
                    :label="item.name"
                    :value="item.id"
                />
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :sm="24" :md="12">
            <el-form-item label="日期:" prop="fictionTime">
              <el-date-picker
                  v-model="state.form.fictionTime"
                  type="date"
                  value-format="YYYY-MM-DD"
                  placeholder="请选择编制日期"
              />
            </el-form-item>
          </el-col>
        </el-row>
        <el-row>
          <el-col :sm="24" :md="12">
            <el-form-item label="审核:" prop="checkId">
              <el-select clearable v-model="state.form.checkId" :disabled="state.title =='查看'" filterable placeholder="审核" style="width: 100%">
                <el-option
                    v-for="item in state.userList"
                    :key="item.id"
                    :label="item.name"
                    :value="item.id"
                />
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :sm="24" :md="12">
            <el-form-item label="日期:" prop="checkTime">
              <el-date-picker
                  v-model="state.form.checkTime"
                  type="date"
                  value-format="YYYY-MM-DD"
                  placeholder="请选择审核日期"
              />
            </el-form-item>
          </el-col>
        </el-row>
        <el-row>
          <el-col :sm="24" :md="12">
            <el-form-item label="批准:" prop="ratifyId">
              <el-select clearable v-model="state.form.ratifyId" :disabled="state.title =='查看'" filterable placeholder="批准" style="width: 100%">
                <el-option
                    v-for="item in state.userList"
                    :key="item.id"
                    :label="item.name"
                    :value="item.id"
                />
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :sm="24" :md="12">
            <el-form-item label="日期:" prop="ratifyTime">
              <el-date-picker
                  v-model="state.form.ratifyTime"
                  type="date"
                  value-format="YYYY-MM-DD"
                  placeholder="请选择批准日期"
              />
            </el-form-item>
          </el-col>
        </el-row>
<!--        <el-form-item label="文件:" prop="filePath">-->
<!--          <el-upload accept=".doc,.docx" :action="state.uploadUrl" :headers="state.header" method="post" :on-success="(res, uploadFile)=>handleAvatarSuccess(res, uploadFile)" :on-exceed="showTip" :limit='state.fileLimit' v-model:file-list="state.fileList" :before-upload="picSize" :on-remove="(file, uploadFiles)=>handleRemove(file, uploadFiles)" >-->
<!--            <el-button type="primary">点击上传</el-button>-->
<!--            <template #tip>-->
<!--              <div class="el-upload__tip">支持上传.doc、.docx格式文档，尺寸小于5M，最多可上传1张</div>-->
<!--            </template>-->
<!--          </el-upload>-->
<!--        </el-form-item>-->
      </el-form>
      <template #footer v-if="state.title !='查看'">
        <span class="dialog-footer">
            <el-button @click="handleClose" size="default">取 消</el-button>
            <el-button type="primary"  @click="onSubmit" size="default" v-preReClick>确认</el-button>
        </span>
      </template>
    </el-dialog>
  </div>
</template>
<script setup>
import {reactive, ref, toRefs, defineEmits, nextTick, onMounted} from 'vue'
import {ElMessage} from "element-plus";
import {addUser, editUser, getUserById, resetPwd} from "@/api/onlineEducation/user"
import {Base64} from "js-base64"
import {getCompany} from "@/api/onlineEducation/company";
import {addIndustryTemp, updateIndustryTemp, updateInfoPlatforms} from "@/api/staffManage/staff";
import {getToken} from "@/utils/auth";
import {delPic} from "@/api/onlineEducation/banner";
import {saveStandardTemp, updateStandardTemp} from "@/api/standardSys/standardSys";
import {
  addManagementPlan,
  addMeetingsList,
  addSelectInconsistent, updateManagementPlan,
  updateMeetingsList,
  updateSelectInconsistent
} from "@/api/innerReview/meetingReview";
import {listUser} from "@/api/system/user";

const emit = defineEmits(["getList"]);
const dialogVisible = ref(false)
const superRef = ref()
const checkFiles = (rule, value, callback) => {
  if (state.fileList.length == 0) {
    callback(new Error('请上传文件'))
  } else {
    callback()
  }
}
const state = reactive({
  title: '',
  form: {
    id: null,
    year: '',
    number: '',
    objective: '',
    content: '',
    location: '',
    staff: '',
    report: '',
    fictionId: null,
    fictionName: '',
    fictionTime: '',
    checkId: null,
    checkName: '',
    checkTime: '',
    ratifyId: null,
    ratifyName: '',
    ratifyTime: '',
    companyId: null
  },
  formRules:{
    year: [{ required: true, message: '请选择年份', trigger: 'blur' }],
    companyId: [{ required: true, message: '请选择企业', trigger: 'blur' }],
    number: [{ required: true, message: '请输入编号', trigger: 'blur' }],
    objective: [{ required: true, message: '请输入评审目的', trigger: 'blur' }],
    content: [{ required: true, message: '请输入评审内容', trigger: 'blur' }],
    location: [{ required: true, message: '请输入评审时间、地点及方式', trigger: 'blur' }],
    staff: [{ required: true, message: '请输入参与评审人员', trigger: 'blur' }],
    report: [{ required: true, message: '请输入管理评审输入报告', trigger: 'blur' }],
    fictionId: [{ required: true, message: '请选择编制人员', trigger: 'blur' }],
    fictionTime: [{ required: true, message: '请选择编制时间', trigger: 'blur' }],
    checkId: [{ required: true, message: '请选择审核人员', trigger: 'blur' }],
    checkTime: [{ required: true, message: '请选择审核时间', trigger: 'blur' }],
    ratifyId: [{ required: true, message: '请选择批准人员', trigger: 'blur' }],
    ratifyTime: [{ required: true, message: '请选择批准时间', trigger: 'blur' }],
  },
  isAdmin: false,
  companyList: [],
  userList: [],
  uploadUrl: import.meta.env.VITE_APP_BASE_API + '/system/common/uploadFile',
  header: {
    Authorization: getToken()
  },
  fileLimit: 1,
  fileList: []
})
onMounted(() => {

});

const openDialog = async (type, value,companyId, isAdmin, companyList) => {
  state.isAdmin = isAdmin
  if(isAdmin){
    state.companyList = companyList
  }
  await getUserList(companyId)
  state.title = type === 'add' ? '新增' : type ==='edit' ? '编辑' : '查看'
  state.form.companyId = companyId
  if(state.title == '编辑'||state.title == '查看'){
    Object.keys(state.form).forEach(key => {
      if (key in value) {
        state.form[key] = value[key]
      }
    })
    console.log(state.form,'form1')
    // if(value.filePath) {
    //   const obj = {
    //     url: value.filePath,
    //     name: '模板文件'
    //   }
    //   state.fileList = [obj]
    // }
  }
  dialogVisible.value = true
}

const getCompanyUser = async (value)=>{
  state.form.fictionId = null
  state.form.checkId = null
  state.form.ratifyId = null
  state.form.fictionName = ''
  state.form.checkName = ''
  state.form.ratifyName = ''
  await getUserList(value)
}

const getUserList = async (companyId)=> {
  const res = await listUser({pageIndex: 1,pageSize: 999, companyId: companyId})
  if(res.code == 200){
    state.userList = res.data.list?res.data.list:[]
  }else{
    ElMessage.warning(res.message)
  }
}

const onSubmit = async () => {
  console.log(state.form,'form2')
  const valid = await superRef.value.validate();
  if(valid){
    state.form.fictionName = state.userList.find(i=>i.id == state.form.fictionId)?.name
    state.form.checkName = state.userList.find(i=>i.id == state.form.checkId)?.name
    state.form.ratifyName = state.userList.find(i=>i.id == state.form.ratifyId)?.name
    if(state.title == '新增'){
      const {id,...data} = state.form
      const res = await addManagementPlan(data)
      if(res.code == 200){
        ElMessage.success(res.message)
        emit('getList')
        handleClose()
        dialogVisible.value = false;
      }else{
        ElMessage.warning(res.message)
      }
    }else{
      const res = await updateManagementPlan(state.form)
      if(res.code == 200){
        ElMessage.success(res.message)
        emit('getList')
        handleClose()
        dialogVisible.value = false;
      }else{
        ElMessage.warning(res.message)
      }
    }
  }
}

const handleAvatarSuccess = (res, uploadFile) => {
  if(res.code == 200){
    state.form.filePath = res.data.path
    state.form.format = '.' + res.data.filename.split('.')[1]
  }else{
    state.fileList = []
    ElMessage({
      type: 'warning',
      message: '文件上传失败'
    })
  }
}

const showTip =()=>{
  ElMessage({
    type: 'warning',
    message: '超出文件上传数量'
  });
}
const picSize = async (rawFile) => {
  if(rawFile.size / 1024 / 1024 > 5){
    ElMessage({
      type: 'warning',
      message: '文件大小不能超过5M'
    });
    return false
  }
};
const handleRemove = async (file, uploadFiles) => {
  let path = state.form.filePath;
  await delPic({path: path}).then(res => {
    if(res.code == 200){
      // ElMessage({
      //   type: 'success',
      //   message: '文件已删除'
      // })
      state.form.filePath = ''
      state.form.format = ''
    }else{
      ElMessage({
        type: 'warning',
        message: res.message
      })
    }
  }).catch(() => {
    state.form.imgUrl = ''
  });
}

const handleClose = () => {
  state.form = {
    id: null,
    year: '',
    number: '',
    objective: '',
    content: '',
    location: '',
    staff: '',
    report: '',
    fictionId: null,
    fictionTime: '',
    checkId: null,
    checkTime: '',
    ratifyId: null,
    ratifyTime: '',
    companyId: null
  }
  state.fileList = []
  superRef.value.clearValidate();
  superRef.value.resetFields()
  dialogVisible.value = false;
}

defineExpose({
  openDialog
});

</script>

<style scoped lang="scss">
.notice{
  :deep(.el-form .el-form-item__label) {
    font-size: 15px;
  }
  .file {
    display: flex;
    flex-direction: column;
    align-items: flex-start;
  }
}
</style>
